---
gitea: none
include_toc: true
---
# dictionaries/rougail/00-base.yml

```yaml
---
version: '1.1'
var:
  description: autosave variable
  auto_save: true
  hidden: true
  default: yes
  mandatory: false
```
